:notoc:

.. puffbird documentation master file, created by

.. module:: puffbird

************************************
Puffbird - handle your *puffy* data!
************************************

**Date**: |today| **Version**: |version|

**Useful links**:
`Binary Installers <https://pypi.org/project/puffbird>`__ |
`Source Repository <https://github.com/gucky92/puffbird>`__ |
`Issues & Ideas <https://github.com/gucky92/puffbird/issues>`__

:mod:`puffbird` is an open source, MIT-licensed library providing an extension to handling
*puffy*
`pandas <https://pandas.pydata.org/>`__ DataFrame objects.
For creating the documentation for :mod:`puffbird`, I used pandas documentation style.

.. raw:: html

    <div class="container">
        <div class="row">
            <div class="col-lg-6 col-md-6 col-sm-6 col-xs-12 d-flex">
                <div class="card text-center intro-card shadow">
                <img src="_static/index_user_guide.svg" class="card-img-top" alt="user guide for puffbird action icon" height="52">
                <div class="card-body flex-fill">
                    <h5 class="card-title">User Guide</h5>
                    <p class="card-text">New to <em>puffbird</em>? Check out the user guide. It
                    contains installation instructions, an introduction to
                    <em>puffbird's</em> main concepts and tutorials.</p>

.. container:: custom-button

    :ref:`User Guide<user_guide>`

.. raw:: html

                </div>
                </div>
            </div>
            <div class="col-lg-6 col-md-6 col-sm-6 col-xs-12 d-flex">
                <div class="card text-center intro-card shadow">
                <img src="_static/index_api.svg" class="card-img-top" alt="api of puffbird action icon" height="52">
                <div class="card-body flex-fill">
                    <h5 class="card-title">API reference</h5>
                    <p class="card-text">The reference guide contains a detailed description of
                    the puffbird API. The reference describes how the methods work and which parameters can
                    be used. It assumes that you have an understanding of the key concepts.</p>

.. container:: custom-button

    :ref:`To the reference guide<api>`

.. raw:: html

                </div>
                </div>
            </div>
        </div>
    </div>


.. toctree::
    :maxdepth: 3
    :hidden:
    :titlesonly:


    user_guide/index
    reference/index
    development/index
    whatsnew/index
